==> ginkgo-hpc-docs-1.7.0-5-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/classes_0.js <==
var searchData=
[
  ['abs_5foperation_0',['abs_operation',['../structgko_1_1accessor_1_1abs__operation.html',1,'gko::accessor']]],
  ['abs_5foperaton_1',['abs_operaton',['../structgko_1_1accessor_1_1abs__operaton.html',1,'gko::accessor']]],
  ['absolutecomputable_2',['AbsoluteComputable',['../classgko_1_1AbsoluteComputable.html',1,'gko']]],
  ['absoluteresidualnorm_3',['AbsoluteResidualNorm',['../classgko_1_1stop_1_1AbsoluteResidualNorm.html',1,'gko::stop']]],
  ['abstractfactory_4',['AbstractFactory',['../classgko_1_1AbstractFactory.html',1,'gko']]],
  ['abstractfactory_3c_20batchlinop_2c_20std_3a_3ashared_5fptr_3c_20const_20batchlinop_20_3e_20_3e_5',['AbstractFactory&lt; BatchLinOp, std::shared_ptr&lt; const BatchLinOp &gt; &gt;',['../classgko_1_1AbstractFactory.html',1,'gko']]],
  ['abstractfactory_3c_20linop_2c_20std_3a_3ashared_5fptr_3c_20const_20linop_20_3e_20_3e_6',['AbstractFactory&lt; LinOp, std::shared_ptr&lt; const LinOp &gt; &gt;',['../classgko_1_1AbstractFactory.html',1,'gko']]],
  ['add_7',['add',['../structgko_1_1accessor_1_1add.html',1,'gko::accessor']]],
  ['allocationerror_8',['AllocationError',['../classgko_1_1AllocationError.html',1,'gko']]],
  ['allocator_9',['Allocator',['../classgko_1_1Allocator.html',1,'gko']]],
  ['amd_10',['Amd',['../classgko_1_1experimental_1_1reorder_1_1Amd.html',1,'gko::experimental::reorder']]],
  ['amd_5fdevice_11',['amd_device',['../classgko_1_1amd__device.html',1,'gko']]],
  ['applywithinitialguess_12',['ApplyWithInitialGuess',['../classgko_1_1solver_1_1ApplyWithInitialGuess.html',1,'gko::solver']]],
  ['are_5fall_5fintegral_13',['are_all_integral',['../structgko_1_1are__all__integral.html',1,'gko']]],
  ['are_5fall_5fintegral_3c_20first_2c_20args_2e_2e_2e_20_3e_14',['are_all_integral&lt; First, Args... &gt;',['../structgko_1_1are__all__integral_3_01First_00_01Args_8_8_8_01_4.html',1,'gko']]],
  ['array_15',['array',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20bool_20_3e_16',['array&lt; bool &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20char_20_3e_17',['array&lt; char &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20comm_5findex_5ftype_20_3e_18',['array&lt; comm_index_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20default_5fprecision_20_3e_19',['array&lt; default_precision &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20gko_3a_3adefault_5fprecision_20_3e_20',['array&lt; gko::default_precision &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20gko_3a_3aprecision_5freduction_20_3e_21',['array&lt; gko::precision_reduction &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20gko_3a_3astopping_5fstatus_20_3e_22',['array&lt; gko::stopping_status &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20global_5findex_5ftype_20_3e_23',['array&lt; global_index_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20index_5ftype_20_3e_24',['array&lt; index_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20indextype_20_3e_25',['array&lt; IndexType &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20int_20_3e_26',['array&lt; int &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20int32_20_3e_27',['array&lt; int32 &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20local_5findex_5ftype_20_3e_28',['array&lt; local_index_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20real_5ftype_20_3e_29',['array&lt; real_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20remove_5fcomplex_3c_20value_5ftype_20_3e_20_3e_30',['array&lt; remove_complex&lt; value_type &gt; &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20size_5ftype_20_3e_31',['array&lt; size_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20unsigned_20char_20_3e_32',['array&lt; unsigned char &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20value_5ftype_20_3e_33',['array&lt; value_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['arrays_34',['arrays',['../structgko_1_1device__matrix__data_1_1arrays.html',1,'gko::device_matrix_data']]],
  ['automatic_35',['automatic',['../classgko_1_1matrix_1_1Hybrid_1_1automatic.html',1,'gko::matrix::Hybrid']]],
  ['automatical_36',['automatical',['../classgko_1_1matrix_1_1Csr_1_1automatical.html',1,'gko::matrix::Csr']]]
];

==> ginkgo-hpc-docs-1.8.0-1-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/classes_0.js <==
var searchData=
[
  ['abs_5foperation_0',['abs_operation',['../structgko_1_1accessor_1_1abs__operation.html',1,'gko::accessor']]],
  ['abs_5foperaton_1',['abs_operaton',['../structgko_1_1accessor_1_1abs__operaton.html',1,'gko::accessor']]],
  ['absolutecomputable_2',['AbsoluteComputable',['../classgko_1_1AbsoluteComputable.html',1,'gko']]],
  ['absoluteresidualnorm_3',['AbsoluteResidualNorm',['../classgko_1_1stop_1_1AbsoluteResidualNorm.html',1,'gko::stop']]],
  ['abstractfactory_4',['AbstractFactory',['../classgko_1_1AbstractFactory.html',1,'gko']]],
  ['abstractfactory_3c_20batchlinop_2c_20std_3a_3ashared_5fptr_3c_20const_20batchlinop_20_3e_20_3e_5',['AbstractFactory&lt; BatchLinOp, std::shared_ptr&lt; const BatchLinOp &gt; &gt;',['../classgko_1_1AbstractFactory.html',1,'gko']]],
  ['abstractfactory_3c_20linop_2c_20std_3a_3ashared_5fptr_3c_20const_20linop_20_3e_20_3e_6',['AbstractFactory&lt; LinOp, std::shared_ptr&lt; const LinOp &gt; &gt;',['../classgko_1_1AbstractFactory.html',1,'gko']]],
  ['add_7',['add',['../structgko_1_1accessor_1_1add.html',1,'gko::accessor']]],
  ['allocationerror_8',['AllocationError',['../classgko_1_1AllocationError.html',1,'gko']]],
  ['allocator_9',['Allocator',['../classgko_1_1Allocator.html',1,'gko']]],
  ['amd_10',['Amd',['../classgko_1_1experimental_1_1reorder_1_1Amd.html',1,'gko::experimental::reorder']]],
  ['amd_5fdevice_11',['amd_device',['../classgko_1_1amd__device.html',1,'gko']]],
  ['applywithinitialguess_12',['ApplyWithInitialGuess',['../classgko_1_1solver_1_1ApplyWithInitialGuess.html',1,'gko::solver']]],
  ['are_5fall_5fintegral_13',['are_all_integral',['../structgko_1_1are__all__integral.html',1,'gko']]],
  ['are_5fall_5fintegral_3c_20first_2c_20args_2e_2e_2e_20_3e_14',['are_all_integral&lt; First, Args... &gt;',['../structgko_1_1are__all__integral_3_01First_00_01Args_8_8_8_01_4.html',1,'gko']]],
  ['array_15',['array',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20bool_20_3e_16',['array&lt; bool &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20char_20_3e_17',['array&lt; char &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20comm_5findex_5ftype_20_3e_18',['array&lt; comm_index_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20default_5fprecision_20_3e_19',['array&lt; default_precision &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20gko_3a_3adefault_5fprecision_20_3e_20',['array&lt; gko::default_precision &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20gko_3a_3aprecision_5freduction_20_3e_21',['array&lt; gko::precision_reduction &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20gko_3a_3astopping_5fstatus_20_3e_22',['array&lt; gko::stopping_status &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20global_5findex_5ftype_20_3e_23',['array&lt; global_index_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20index_5ftype_20_3e_24',['array&lt; index_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20indextype_20_3e_25',['array&lt; IndexType &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20int32_20_3e_26',['array&lt; int32 &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20int64_20_3e_27',['array&lt; int64 &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20local_5findex_5ftype_20_3e_28',['array&lt; local_index_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20localindextype_20_3e_29',['array&lt; LocalIndexType &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20real_5ftype_20_3e_30',['array&lt; real_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20remove_5fcomplex_3c_20value_5ftype_20_3e_20_3e_31',['array&lt; remove_complex&lt; value_type &gt; &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20size_5ftype_20_3e_32',['array&lt; size_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20t_20_3e_33',['array&lt; T &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20unsigned_20char_20_3e_34',['array&lt; unsigned char &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['array_3c_20value_5ftype_20_3e_35',['array&lt; value_type &gt;',['../classgko_1_1array.html',1,'gko']]],
  ['arrays_36',['arrays',['../structgko_1_1device__matrix__data_1_1arrays.html',1,'gko::device_matrix_data']]],
  ['automatic_37',['automatic',['../classgko_1_1matrix_1_1Hybrid_1_1automatic.html',1,'gko::matrix::Hybrid']]],
  ['automatical_38',['automatical',['../classgko_1_1matrix_1_1Csr_1_1automatical.html',1,'gko::matrix::Csr']]]
];
